summaryrefslogtreecommitdiffstats
path: root/multi.c
diff options
context:
space:
mode:
Diffstat (limited to 'multi.c')
-rw-r--r--multi.c3
1 files changed, 2 insertions, 1 deletions
diff --git a/multi.c b/multi.c
index 7f77cb8..7ea64b4 100644
--- a/multi.c
+++ b/multi.c
@@ -1458,8 +1458,9 @@ multi_connection_established (struct multi_context *m, struct multi_instance *mi
ASSERT (mi->context.c1.tuntap);
/* lock down the common name so it can't change during future TLS renegotiations */
tls_lock_common_name (mi->context.c2.tls_multi);
+ tls_lock_cert_hash_set (mi->context.c2.tls_multi);
/* generate a msg() prefix for this client instance */
generate_prefix (mi);
@@ -1458,8 +1458,9 @@ multi_connection_established (struct multi_context *m, struct multi_instance *mi
ASSERT (mi->context.c1.tuntap);
- /* lock down the common name so it can't change during future TLS renegotiations */
+ /* lock down the common name and cert hashes so they can't change during future TLS renegotiations */
tls_lock_common_name (mi->context.c2.tls_multi);